var NAVTREEINDEX16 =
{
"page_spa_design.html#autotoc_md130":[9,4,0,2],
"page_spa_plugins.html":[9,5],
"page_spa_plugins.html#autotoc_md115":[9,5,0],
"page_spa_plugins.html#autotoc_md116":[9,5,1],
"page_spa_plugins.html#autotoc_md117":[9,5,2],
"page_spa_plugins.html#autotoc_md118":[9,5,3],
"page_spa_plugins.html#autotoc_md119":[9,5,4],
"page_spa_plugins.html#autotoc_md120":[9,5,5],
"page_spa_plugins.html#autotoc_md121":[9,5,6],
"page_spa_plugins.html#autotoc_md122":[9,5,7],
"page_spa_plugins.html#autotoc_md123":[9,5,8],
"page_spa_plugins.html#autotoc_md124":[9,5,8,0],
"page_spa_plugins.html#autotoc_md125":[9,5,8,1],
"page_spa_plugins.html#autotoc_md126":[9,5,9],
"page_spa_pod.html":[9,6],
"page_spa_pod.html#autotoc_md131":[9,6,0],
"page_spa_pod.html#autotoc_md132":[9,6,1],
"page_spa_pod.html#autotoc_md133":[9,6,1,0],
"page_spa_pod.html#autotoc_md134":[9,6,1,1],
"page_spa_pod.html#autotoc_md135":[9,6,1,2],
"page_spa_pod.html#autotoc_md136":[9,6,1,3],
"page_spa_pod.html#autotoc_md137":[9,6,1,4],
"page_spa_pod.html#autotoc_md138":[9,6,2],
"page_spa_pod.html#autotoc_md139":[9,6,2,0],
"page_spa_pod.html#autotoc_md140":[9,6,2,1],
"page_spa_pod.html#autotoc_md141":[9,6,2,2],
"page_spa_pod.html#autotoc_md142":[9,6,2,3],
"page_spa_pod.html#autotoc_md143":[9,6,2,4],
"page_spa_pod.html#autotoc_md144":[9,6,2,5],
"page_spa_pod.html#autotoc_md145":[9,6,2,6],
"page_spa_pod.html#autotoc_md146":[9,6,3],
"page_spa_pod.html#autotoc_md147":[9,6,4],
"page_streams.html":[8,2],
"page_streams.html#sec_buffers":[8,2,4],
"page_streams.html#sec_connect":[8,2,2],
"page_streams.html#sec_create":[8,2,1],
"page_streams.html#sec_format":[8,2,3],
"page_streams.html#sec_overview":[8,2,0],
"page_streams.html#sec_stream_configuration":[8,2,7],
"page_streams.html#sec_stream_disconnect":[8,2,6],
"page_streams.html#sec_stream_environment":[8,2,8],
"page_streams.html#sec_streaming":[8,2,5],
"page_streams.html#ssec_config_properties":[8,2,7,0],
"page_streams.html#ssec_config_rules":[8,2,7,1],
"page_streams.html#ssec_consume":[8,2,5,0],
"page_streams.html#ssec_produce":[8,2,5,1],
"page_streams.html#ssec_stream_formats":[8,2,2,1],
"page_streams.html#ssec_stream_target":[8,2,2,0],
"page_thread_loop.html":[8,3],
"page_thread_loop.html#sec_thread_loop_create":[8,3,1],
"page_thread_loop.html#sec_thread_loop_destruction":[8,3,2],
"page_thread_loop.html#sec_thread_loop_events":[8,3,4],
"page_thread_loop.html#sec_thread_loop_locking":[8,3,3],
"page_thread_loop.html#sec_thread_loop_overview":[8,3,0],
"page_tools.html":[5,12],
"page_tutorial.html":[7],
"page_tutorial.html#autotoc_md108":[7,0],
"page_tutorial1.html":[7,1],
"page_tutorial1.html#autotoc_md109":[7,1,0],
"page_tutorial1.html#autotoc_md110":[7,1,1],
"page_tutorial2.html":[7,2],
"page_tutorial3.html":[7,3],
"page_tutorial4.html":[7,4],
"page_tutorial5.html":[7,5],
"page_tutorial6.html":[7,6],
"pages.html":[],
"param_2audio_2format_8h.html":[10,8,7,1],
"param_2audio_2type-info_8h.html":[10,8,7,5],
"param_2bluetooth_2type-info_8h.html":[10,8,7,7],
"param_2format_8h.html":[10,8,7,8],
"param_2type-info_8h.html":[10,8,7,11],
"param_2video_2format_8h.html":[10,8,7,15],
"param_2video_2type-info_8h.html":[10,8,7,18],
"param_8h.html":[10,8,7,9],
"parser_8h.html":[10,8,0,6],
"permission_8h.html":[10,4,11,0],
"pipewire_8h.html":[10,4,0,0],
"plugin-loader_8h.html":[10,8,9,6,0],
"plugin_8h.html":[10,8,9,5,0],
"pod_2command_8h.html":[10,8,0,1],
"pod_2event_8h.html":[10,8,0,3],
"pod_2pod_8h.html":[10,8,0,7],
"port_8h.html":[10,4,12,0],
"properties_8h.html":[10,6,6,0],
"protocol-native_8h.html":[10,7,3,0],
"protocol_8h.html":[10,5,13,0],
"proxy_8h.html":[10,4,13,0],
"pwtest_8h.html":[10,2,0],
"resource_8h.html":[10,5,14,0],
"result_8h.html":[10,8,8,9,0],
"ringbuffer_8h.html":[10,8,8,10,0],
"session-manager_8h.html":[10,7,4,0],
"spa_2examples_2adapter-control_8c-example.html":[13,25],
"spa_2examples_2example-control_8c-example.html":[13,26],
"spa_2examples_2local-libcamera_8c-example.html":[13,27],
"spa_2examples_2local-v4l2_8c-example.html":[13,28],
"spa_2include_2spa_2control_2control_8h.html":[10,8,2,0],
"spa_2include_2spa_2debug_2log_8h.html":[10,8,3,3],
"spa_2include_2spa_2debug_2mem_8h.html":[10,8,3,4],
"spa_2include_2spa_2debug_2node_8h.html":[10,8,3,5],
"spa_2include_2spa_2monitor_2device_8h.html":[10,8,4,0],
"spa_2include_2spa_2node_2keys_8h.html":[10,8,6,3],
"spa_2include_2spa_2node_2node_8h.html":[10,8,6,4],
"spa_2include_2spa_2param_2profiler_8h.html":[10,8,7,10],
"spa_2include_2spa_2pod_2filter_8h.html":[10,8,0,4],
"spa_2include_2spa_2support_2i18n_8h.html":[10,8,9,2,0],
"spa_2include_2spa_2support_2log_8h.html":[10,8,9,3,1],
"spa_2include_2spa_2support_2loop_8h.html":[10,8,9,4,0],
"spa_2include_2spa_2support_2thread_8h.html":[10,8,9,8,0],
"spa_2include_2spa_2utils_2keys_8h.html":[10,8,8,7,0],
"spa_2include_2spa_2utils_2type_8h.html":[10,8,8,12,1],
"src_2pipewire_2control_8h.html":[10,5,10,0],
"src_2pipewire_2device_8h.html":[10,4,5,0],
"src_2pipewire_2extensions_2profiler_8h.html":[10,7,2,0],
"src_2pipewire_2extensions_2session-manager_2keys_8h.html":[10,7,4,5],
"src_2pipewire_2filter_8h.html":[10,1,0],
"src_2pipewire_2i18n_8h.html":[10,6,2,0],
"src_2pipewire_2keys_8h.html":[10,4,16,0],
"src_2pipewire_2log_8h.html":[10,6,3,0],
"src_2pipewire_2loop_8h.html":[10,4,8,0],
"src_2pipewire_2mem_8h.html":[10,6,5,0],
"src_2pipewire_2node_8h.html":[10,4,10,0],
"src_2pipewire_2thread_8h.html":[10,6,7,0],
"src_2pipewire_2type_8h.html":[10,4,15,0],
"stream_8h.html":[10,0,0],
"string_8h.html":[10,8,8,11,0],
"structitimerspec.html":[11,0,0],
"structpw__array.html":[10,6,0,1],
"structpw__array.html#a3d468425a1a0084f98301e2fd9becc6b":[10,6,0,1,1],
"structpw__array.html#a429b934f5c1580d91af238ac04e44842":[10,6,0,1,2],
"structpw__array.html#a92ae2df32c3d6935897f41b6e7f5ad3c":[10,6,0,1,3],
"structpw__array.html#ab0929cdf2f7acb291f2f17be299b8ea5":[10,6,0,1,0],
"structpw__buffer.html":[10,0,1],
"structpw__buffer.html#a925734b861209896789573f3b94a61c1":[10,0,1,2],
"structpw__buffer.html#ab5fe741ec31686febdbc602098945f08":[10,0,1,3],
"structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090":[10,0,1,0],
"structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96":[10,0,1,1],
"structpw__buffers.html":[10,5,9,1],
"structpw__buffers.html#ac6dff2ff3c481e5b092fca206e0c144f":[10,5,9,1,3],
"structpw__buffers.html#ad2d1496ce9316c04921470078b8046c5":[10,5,9,1,2],
"structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed":[10,5,9,1,1],
"structpw__buffers.html#af915317f3448e471390a13c48c0d873e":[10,5,9,1,0],
"structpw__client.html":[10,4,3,4],
"structpw__client__endpoint.html":[10,7,4,22],
"structpw__client__endpoint__events.html":[10,7,4,6],
"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1":[10,7,4,6,4],
"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[10,7,4,6,1],
"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1":[10,7,4,6,3],
"structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6":[10,7,4,6,2],
"structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e":[10,7,4,6,0],
"structpw__client__endpoint__methods.html":[10,7,4,7],
"structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850":[10,7,4,7,1],
"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0":[10,7,4,7,0],
"structpw__client__events.html":[10,4,3,2],
"structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[10,4,3,2,0],
"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[10,4,3,2,1],
"structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[10,4,3,2,2],
"structpw__client__info.html":[10,4,3,1],
"structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[10,4,3,1,0],
"structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[10,4,3,1,1],
"structpw__client__methods.html":[10,4,3,3],
"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,4,3,3,3],
"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07":[10,4,3,3,5],
"structpw__client__methods.html#a298f33a5d81477d06b08f52d233b740a":[10,4,3,3,2],
"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,4,3,3,4],
"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,4,3,3,0],
"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,4,3,3,1],
"structpw__client__node.html":[10,7,0,4],
"structpw__client__node__buffer.html":[10,7,0,1],
"structpw__client__node__buffer.html#a003e6b6549d0dbd9e2c8a6030a1cfa85":[10,7,0,1,2],
"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392":[10,7,0,1,0],
"structpw__client__node__buffer.html#a1d524a38ed82fb88371d741bcb1e3ff0":[10,7,0,1,1],
"structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3":[10,7,0,1,3],
"structpw__client__node__events.html":[10,7,0,2],
"structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
"structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7],
"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4":[10,7,0,2,0],
"structpw__client__node__events.html#a63c10e914836b4c4ffc02be889c717f8":[10,7,0,2,8],
"structpw__client__node__events.html#a775ca4ec6d6115039b2e8574bef184f2":[10,7,0,2,4],
"structpw__client__node__events.html#aa25eeb692995699b672f71251ec0b4b6":[10,7,0,2,11],
"structpw__client__node__events.html#ab1aba9806056fc945c2328f1cc128f6e":[10,7,0,2,12],
"structpw__client__node__events.html#abac4b80ae987a95a81ece32baa8fef14":[10,7,0,2,5],
"structpw__client__node__events.html#abb5194c288d8bb436b1c8264e21037c7":[10,7,0,2,3],
"structpw__client__node__events.html#ac0b5a3c66103be01b784464d4dd81fa0":[10,7,0,2,6],
"structpw__client__node__events.html#ac5884f60926b382728097c8846dcba85":[10,7,0,2,2],
"structpw__client__node__events.html#ad7084094ae633b01409033ba363ef78b":[10,7,0,2,1],
"structpw__client__node__methods.html":[10,7,0,3],
"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
"structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
"structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
"structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5],
"structpw__client__session.html":[10,7,4,23],
"structpw__client__session__events.html":[10,7,4,8],
"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f":[10,7,4,8,0],
"structpw__client__session__events.html#a8e823bcde1844c0857314b10069f3b8d":[10,7,4,8,1],
"structpw__client__session__events.html#aae0dc344c9b1d62b21fb16e4fc2c9c33":[10,7,4,8,3],
"structpw__client__session__events.html#af3eab807465363845550f89f1bb9d816":[10,7,4,8,2],
"structpw__client__session__methods.html":[10,7,4,9],
"structpw__client__session__methods.html#a4537bb47cfe11b27649ffe082fdd49fa":[10,7,4,9,0],
"structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a":[10,7,4,9,1],
"structpw__context.html":[10,4,2,3],
"structpw__context__events.html":[10,4,2,1],
"structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,4,2,1,4],
"structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,4,2,1,1],
"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,4,2,1,5],
"structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,4,2,1,2],
"structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,4,2,1,0],
"structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,4,2,1,3],
"structpw__control.html":[10,5,10,2],
"structpw__control.html":[10,5,8,4],
"structpw__control__events.html":[10,5,10,1],
"structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,5,10,1,4],
"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,5,10,1,0],
"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,5,10,1,2],
"structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,5,10,1,1],
"structpw__control__events.html#adbd47ebc650888ca6235b763fa3f6ef2":[10,5,10,1,3],
"structpw__core.html":[10,4,4,4],
"structpw__core__events.html":[10,4,4,2],
"structpw__core__events.html#a20931e5073a743e26c70957f85c10fd8":[10,4,4,2,3],
"structpw__core__events.html#a28cd6e2263efb69df702822028a45df2":[10,4,4,2,8],
"structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56":[10,4,4,2,4],
"structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131":[10,4,4,2,7],
"structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1],
"structpw__core__events.html#a8a700a03453729d52d96112647125303":[10,4,4,2,5],
"structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,4,4,2,0],
"structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976":[10,4,4,2,6],
"structpw__core__events.html#acc0442d3b7d94005c8c63e5bd7b89473":[10,4,4,2,2],
"structpw__core__info.html":[10,4,4,1],
"structpw__core__info.html#a25d93390dbafcb433827ec29c195404f":[10,4,4,1,5],
"structpw__core__info.html#a3e394e50023a597dafb391887249d4eb":[10,4,4,1,4],
"structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083":[10,4,4,1,1],
"structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca":[10,4,4,1,0],
"structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42":[10,4,4,1,2],
"structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f":[10,4,4,1,3],
"structpw__core__methods.html":[10,4,4,3],
"structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703":[10,4,4,3,1],
"structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9":[10,4,4,3,4],
"structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309":[10,4,4,3,8],
"structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5":[10,4,4,3,2],
"structpw__core__methods.html#a570886edc43416b3dcd10b48016493af":[10,4,4,3,6],
"structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce":[10,4,4,3,7],
"structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,4,4,3,5],
"structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176":[10,4,4,3,3],
"structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a":[10,4,4,3,0],
"structpw__data__loop.html":[10,5,11,2],
"structpw__data__loop__events.html":[10,5,11,1],
"structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,5,11,1,0]
};
